==> safeid-1.0.tar.gz: safeid-1.0/setup.py <==
"""
PIP setup script for the SafeID package.
"""

from setuptools import setup

def readme():
    with open('README.rst') as f:
        return f.read()

description=\
  """
  SafeID is a proof-of-concept web server library that protects user passwords
  using the Pythia protocol. Web servers can interact with a Pythia server 
  to encrypt new passwords and verify existing passwords.
  """
description = ' '.join(description.split())

setup(name='safeid',
      version='1.0',
      description=description,
      classifiers=[
          'Development Status :: 4 - Beta',
          'Intended Audience :: Developers',
          'Intended Audience :: Information Technology',
          'License :: OSI Approved :: MIT License',
          'Operating System :: MacOS',
          'Operating System :: MacOS :: MacOS X',
          'Operating System :: POSIX :: Linux',
          'Operating System :: Unix',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 2.7',
          'Topic :: Security', 
          'Topic :: Security :: Cryptography',
          'Topic :: System :: Systems Administration :: Authentication/Directory',
      ],
      url='http://pages.cs.wisc.edu/~ace/pythia.html',
      download_url='https://bitbucket.org/ace0/safeid/get/1.0.zip',
      author='Adam Everspaugh',
      author_email='ace@cs.wisc.edu',
      license='MIT',
      keywords='password encryption authentication',
      packages=['safeid'],
      # TODO: Add pythia package once we have a name for it.
      install_requires=['httplib2', 'pythia'],
      zip_safe=False, 
      entry_points={ 'console_scripts': [ 'safeid = safeid.safeid:main' ] },
    )

==> safeid-1.1.tar.gz: safeid-1.1/setup.py <==
"""
PIP setup script for the SafeID package.
"""

from setuptools import setup

def readme():
    with open('README.rst') as f:
        return f.read()

description=\
  """
  SafeID is a proof-of-concept web server library that protects user passwords
  using the Pythia protocol. Web servers can interact with a Pythia server 
  to encrypt new passwords and verify existing passwords.
  """
description = ' '.join(description.split())

setup(name='safeid',
      version='1.1',
      description=description,
      classifiers=[
          'Development Status :: 4 - Beta',
          'Intended Audience :: Developers',
          'Intended Audience :: Information Technology',
          'License :: OSI Approved :: MIT License',
          'Operating System :: MacOS',
          'Operating System :: MacOS :: MacOS X',
          'Operating System :: POSIX :: Linux',
          'Operating System :: Unix',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 2.7',
          'Topic :: Security', 
          'Topic :: Security :: Cryptography',
          'Topic :: System :: Systems Administration :: Authentication/Directory',
      ],
      url='http://pages.cs.wisc.edu/~ace/pythia.html',
      download_url='https://bitbucket.org/ace0/safeid/get/1.0.zip',
      author='Adam Everspaugh',
      author_email='ace@cs.wisc.edu',
      license='MIT',
      keywords='password encryption authentication',
      packages=['safeid'],
      install_requires=['httplib2', 'pythiacrypto'],
      zip_safe=False, 
      entry_points={ 'console_scripts': [ 'safeid = safeid.safeid:main' ] },
    )
